@@ -1,10 +1,11 @@
 import asyncio
+import copy
 import logging
 import traceback
 from asyncio import StreamReader, FIRST_EXCEPTION
 from datetime import datetime, timezone, timedelta
 from subprocess import PIPE, STDOUT, Popen
-from typing import List, Tuple, Optional, Dict, TypeAlias, Callable, Any
+from typing import List, Tuple, Optional, Dict, TypeAlias, Callable, Any, Union
 
 from dateutil.parser import parse as dateutil_parse
 
@@ -28,6 +29,40 @@ def parse_rfc3339(date_str: str) -> datetime:
     return res
 
 
+def _helper_convert_dict_datetimes_to_rfc3339(
+    a_dict_or_list: Union[Dict, List], *, no_milliseconds=True
+) -> List[Union[Dict, List]]:
+    res = []
+    if isinstance(a_dict_or_list, Dict):
+        for key, value in a_dict_or_list.items():
+            if isinstance(value, List) or isinstance(value, dict):
+                res.append(value)
+            if isinstance(value, datetime):
+                a_dict_or_list[key] = dump_rfc3339(
+                    value, no_milliseconds=no_milliseconds
+                )
+    elif isinstance(a_dict_or_list, List):
+        for i in range(len(a_dict_or_list)):
+            value = a_dict_or_list[i]
+            if isinstance(value, List) or isinstance(value, dict):
+                res.append(value)
+            if isinstance(value, datetime):
+                a_dict_or_list[i] = dump_rfc3339(value, no_milliseconds=no_milliseconds)
+    return res
+
+
+def convert_dict_datetimes_to_rfc3339(a_dict: Dict) -> Dict:
+    """
+    :param a_dict:
+    :return: a deep copy of a_dict, but with each datetime anywhere, replaces by its representatino as a RFC3339 string
+    """
+    res = copy.deepcopy(a_dict)
+    todo = [res]
+    while todo:
+        todo.extend(_helper_convert_dict_datetimes_to_rfc3339(todo.pop()))
+    return res
+
+
 def datetime_now(*, zulu=False, no_milliseconds=False) -> datetime:
     res = datetime.now(timezone.utc)
     if not zulu:
